==> blueprint-component-mapper-3.15.3.tgz: package/esm/dual-list-select/dual-list-select.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import PropTypes from 'prop-types';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import { Menu } from "@blueprintjs/core/lib/esm/components/menu/menu.js";
import { MenuItem } from "@blueprintjs/core/lib/esm/components/menu/menuItem.js";
import { ButtonGroup } from "@blueprintjs/core/lib/esm/components/button/buttonGroup.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { ControlGroup } from "@blueprintjs/core/lib/esm/components/forms/controlGroup.js";
import { InputGroup } from "@blueprintjs/core/lib/esm/components/forms/inputGroup.js";
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { FormGroupInternal } from '../form-group/form-group';
var useStyles = createUseStyles({
  menu: {
    height: '80%',
    overflow: 'auto'
  },
  buttonGroup: {
    justifyContent: 'center'
  },
  wrapper: {
    display: 'flex',
    justifyContent: 'space-evenly',
    minHeight: 250
  },
  '@media (max-width: 768px)': {
    wrapper: {
      flexDirection: 'column'
    }
  }
});

var List = function List(_ref) {
  var value = _ref.value,
      optionClick = _ref.optionClick,
      noOptionsTitle = _ref.noOptionsTitle,
      filterValue = _ref.filterValue,
      filterValueText = _ref.filterValueText,
      selectedValues = _ref.selectedValues,
      MenuProps = _ref.MenuProps,
      MenuItemProps = _ref.MenuItemProps;

  var _useStyles = useStyles(),
      menu = _useStyles.menu;

  return /*#__PURE__*/React.createElement(Menu, _extends({}, MenuProps, {
    className: clsx('bp3-elevation-1', menu, MenuProps.className)
  }), value.length < 1 && /*#__PURE__*/React.createElement(MenuItem, _extends({
    text: filterValue ? filterValueText : noOptionsTitle,
    disabled: true
  }, MenuItemProps)), value.length > 0 && value.map(function (_ref2) {
    var value = _ref2.value,
        label = _ref2.label,
        ItemMenuItemProps = _ref2.MenuItemProps;
    return /*#__PURE__*/React.createElement(MenuItem, _extends({
      onClick: function onClick(e) {
        return optionClick(e, value);
      },
      key: value,
      active: selectedValues.includes(value),
      text: label
    }, MenuItemProps, ItemMenuItemProps));
  }));
};

List.propTypes = {
  value: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })),
  optionClick: PropTypes.func.isRequired,
  noOptionsTitle: PropTypes.node,
  filterValue: PropTypes.string,
  filterValueText: PropTypes.node,
  selectedValues: PropTypes.array,
  checkboxVariant: PropTypes.bool,
  MenuProps: PropTypes.object,
  MenuItemProps: PropTypes.object
};
List.defaultProps = {
  value: [],
  MenuProps: {},
  MenuItemProps: {}
};

var Toolbar = function Toolbar(_ref3) {
  var sortTitle = _ref3.sortTitle,
      onFilter = _ref3.onFilter,
      onSort = _ref3.onSort,
      sortDirection = _ref3.sortDirection,
      value = _ref3.value,
      placeholder = _ref3.placeholder,
      ControlGroupProps = _ref3.ControlGroupProps,
      InputGroupProps = _ref3.InputGroupProps,
      ButtonProps = _ref3.ButtonProps;
  return /*#__PURE__*/React.createElement(ControlGroup, ControlGroupProps, /*#__PURE__*/React.createElement(InputGroup, _extends({
    placeholder: placeholder,
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    value: value
  }, InputGroupProps)), /*#__PURE__*/React.createElement(Button, _extends({
    icon: sortDirection ? 'sort-desc' : 'sort-asc',
    title: sortTitle,
    onClick: onSort
  }, ButtonProps)));
};

Toolbar.propTypes = {
  sortTitle: PropTypes.node,
  onFilter: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  sortDirection: PropTypes.bool,
  value: PropTypes.string,
  placeholder: PropTypes.string,
  ControlGroupProps: PropTypes.object,
  InputGroupProps: PropTypes.object,
  ButtonProps: PropTypes.object
};
Toolbar.defaultProps = {
  ControlGroupProps: {},
  InputGroupProps: {},
  ButtonProps: {}
};

var DualListInternal = function DualListInternal(_ref4) {
  var allToRight = _ref4.allToRight,
      allToLeft = _ref4.allToLeft,
      leftTitle = _ref4.leftTitle,
      moveAllLeftTitle = _ref4.moveAllLeftTitle,
      moveAllRightTitle = _ref4.moveAllRightTitle,
      moveRightTitle = _ref4.moveRightTitle,
      moveLeftTitle = _ref4.moveLeftTitle,
      rightTitle = _ref4.rightTitle,
      noValueTitle = _ref4.noValueTitle,
      noOptionsTitle = _ref4.noOptionsTitle,
      filterOptionsTitle = _ref4.filterOptionsTitle,
      filterValueTitle = _ref4.filterValueTitle,
      filterValueText = _ref4.filterValueText,
      filterOptionsText = _ref4.filterOptionsText,
      state = _ref4.state,
      sortOptions = _ref4.sortOptions,
      filterOptions = _ref4.filterOptions,
      handleOptionsClick = _ref4.handleOptionsClick,
      leftValues = _ref4.leftValues,
      handleMoveRight = _ref4.handleMoveRight,
      handleMoveLeft = _ref4.handleMoveLeft,
      handleClearLeftValues = _ref4.handleClearLeftValues,
      handleClearRightValues = _ref4.handleClearRightValues,
      sortValues = _ref4.sortValues,
      filterValues = _ref4.filterValues,
      rightValues = _ref4.rightValues,
      handleValuesClick = _ref4.handleValuesClick,
      WrapperProps = _ref4.WrapperProps,
      LeftWrapperProps = _ref4.LeftWrapperProps,
      RightWrapperProps = _ref4.RightWrapperProps,
      ButtonGroupProps = _ref4.ButtonGroupProps,
      ToRightButtonProps = _ref4.ToRightButtonProps,
      AllToRightButtonProps = _ref4.AllToRightButtonProps,
      AllToLeftButtonProps = _ref4.AllToLeftButtonProps,
      ToLeftButtonProps = _ref4.ToLeftButtonProps,
      LeftControlGroupProps = _ref4.LeftControlGroupProps,
      LeftInputGroupProps = _ref4.LeftInputGroupProps,
      LeftButtonProps = _ref4.LeftButtonProps,
      RightControlGroupProps = _ref4.RightControlGroupProps,
      RightInputGroupProps = _ref4.RightInputGroupProps,
      RightButtonProps = _ref4.RightButtonProps,
      LeftMenuProps = _ref4.LeftMenuProps,
      LeftMenuItemProps = _ref4.LeftMenuItemProps,
      RightMenuProps = _ref4.RightMenuProps,
      RightMenuItemProps = _ref4.RightMenuItemProps;

  var _useStyles2 = useStyles(),
      buttonGroup = _useStyles2.buttonGroup,
      wrapper = _useStyles2.wrapper;

  return /*#__PURE__*/React.createElement("div", _extends({}, WrapperProps, {
    className: clsx(wrapper, WrapperProps.className)
  }), /*#__PURE__*/React.createElement("div", LeftWrapperProps, leftTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    onFilter: filterOptions,
    value: state.filterOptions,
    placeholder: filterOptionsTitle,
    ControlGroupProps: LeftControlGroupProps,
    InputGroupProps: LeftInputGroupProps,
    ButtonProps: LeftButtonProps
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleOptionsClick,
    value: leftValues,
    noOptionsTitle: noOptionsTitle,
    filterValue: state.filterOptions,
    filterValueText: filterOptionsText,
    selectedValues: state.selectedLeftValues,
    MenuProps: LeftMenuProps,
    MenuItemProps: LeftMenuItemProps
  })), /*#__PURE__*/React.createElement(ButtonGroup, _extends({
    vertical: true,
    alignText: "center"
  }, ButtonGroupProps, {
    className: clsx(buttonGroup, ButtonGroupProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedLeftValues.length === 0,
    onClick: handleMoveRight,
    title: moveRightTitle,
    icon: "chevron-right"
  }, ToRightButtonProps)), allToRight && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: leftValues.length === 0,
    onClick: handleClearLeftValues,
    title: moveAllRightTitle,
    icon: "double-chevron-right"
  }, AllToRightButtonProps)), allToLeft && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: rightValues.length === 0,
    onClick: handleClearRightValues,
    title: moveAllLeftTitle,
    icon: "double-chevron-left"
  }, AllToLeftButtonProps)), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedRightValues.length === 0,
    onClick: handleMoveLeft,
    title: moveLeftTitle,
    icon: "chevron-left"
  }, ToLeftButtonProps))), /*#__PURE__*/React.createElement("div", RightWrapperProps, rightTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    onFilter: filterValues,
    value: state.filterValue,
    placeholder: filterValueTitle,
    ControlGroupProps: RightControlGroupProps,
    InputGroupProps: RightInputGroupProps,
    ButtonProps: RightButtonProps
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleValuesClick,
    value: rightValues,
    noOptionsTitle: noValueTitle,
    filterValue: state.filterValue,
    filterValueText: filterValueText,
    selectedValues: state.selectedRightValues,
    MenuProps: RightMenuProps,
    MenuItemProps: RightMenuItemProps
  })));
};

DualListInternal.propTypes = {
  leftTitle: PropTypes.node,
  rightTitle: PropTypes.node,
  moveLeftTitle: PropTypes.node,
  moveRightTitle: PropTypes.node,
  allToLeft: PropTypes.bool,
  allToRight: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  moveAllLeftTitle: PropTypes.node,
  moveAllRightTitle: PropTypes.node,
  noValueTitle: PropTypes.node,
  noOptionsTitle: PropTypes.node,
  filterOptionsTitle: PropTypes.node,
  filterValueTitle: PropTypes.node,
  filterValueText: PropTypes.node,
  filterOptionsText: PropTypes.node,
  state: PropTypes.object,
  sortOptions: PropTypes.func,
  filterOptions: PropTypes.func,
  handleOptionsClick: PropTypes.func,
  leftValues: PropTypes.array,
  handleMoveRight: PropTypes.func,
  handleMoveLeft: PropTypes.func,
  handleClearLeftValues: PropTypes.func,
  handleClearRightValues: PropTypes.func,
  sortValues: PropTypes.func,
  filterValues: PropTypes.func,
  rightValues: PropTypes.array,
  handleValuesClick: PropTypes.func,
  WrapperProps: PropTypes.object,
  LeftWrapperProps: PropTypes.object,
  RightWrapperProps: PropTypes.object,
  ButtonGroupProps: PropTypes.object,
  ToRightButtonProps: PropTypes.object,
  AllToRightButtonProps: PropTypes.object,
  AllToLeftButtonProps: PropTypes.object,
  ToLeftButtonProps: PropTypes.object,
  LeftControlGroupProps: PropTypes.object,
  LeftInputGroupProps: PropTypes.object,
  LeftButtonProps: PropTypes.object,
  RightControlGroupProps: PropTypes.object,
  RightInputGroupProps: PropTypes.object,
  RightButtonProps: PropTypes.object,
  LeftMenuProps: PropTypes.object,
  LeftMenuItemProps: PropTypes.object,
  RightMenuProps: PropTypes.object,
  RightMenuItemProps: PropTypes.object
};
DualListInternal.defaultProps = {
  leftTitle: 'Options',
  rightTitle: 'Selected',
  moveLeftTitle: 'Move selected to left',
  moveRightTitle: 'Move selected to right',
  moveAllRightTitle: 'Move all to right',
  moveAllLeftTitle: 'Move all to left',
  noOptionsTitle: 'No available options',
  noValueTitle: 'No selected',
  filterOptionsTitle: 'Filter options',
  filterValueTitle: 'Filter selected value',
  filterOptionsText: 'Remove your filter to see all options',
  filterValueText: 'Remove your filter to see all selected',
  options: [],
  allToLeft: true,
  allToRight: true,
  WrapperProps: {},
  LeftWrapperProps: {},
  RightWrapperProps: {},
  ButtonGroupProps: {},
  ToRightButtonProps: {},
  AllToRightButtonProps: {},
  AllToLeftButtonProps: {},
  ToLeftButtonProps: {},
  LeftControlGroupProps: {},
  LeftInputGroupProps: {},
  LeftButtonProps: {},
  RightControlGroupProps: {},
  RightInputGroupProps: {},
  RightButtonProps: {},
  LeftMenuProps: {},
  LeftMenuItemProps: {},
  RightMenuProps: {},
  RightMenuItemProps: {}
};

var DualListWrapper = function DualListWrapper(props) {
  return /*#__PURE__*/React.createElement(FormGroupInternal, _extends({}, props, {
    Component: DualListInternal
  }));
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualListWrapper
  }));
};

export default DualListSelect;

==> blueprint-component-mapper-3.16.8.tgz: package/esm/dual-list-select/dual-list-select.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import PropTypes from 'prop-types';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import { Menu } from "@blueprintjs/core/lib/esm/components/menu/menu.js";
import { MenuItem } from "@blueprintjs/core/lib/esm/components/menu/menuItem.js";
import { ButtonGroup } from "@blueprintjs/core/lib/esm/components/button/buttonGroup.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { ControlGroup } from "@blueprintjs/core/lib/esm/components/forms/controlGroup.js";
import { InputGroup } from "@blueprintjs/core/lib/esm/components/forms/inputGroup.js";
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { FormGroupInternal } from '../form-group/form-group';
var useStyles = createUseStyles({
  menu: {
    height: '80%',
    overflow: 'auto'
  },
  buttonGroup: {
    justifyContent: 'center'
  },
  wrapper: {
    display: 'flex',
    justifyContent: 'space-evenly',
    minHeight: 250
  },
  '@media (max-width: 768px)': {
    wrapper: {
      flexDirection: 'column'
    }
  }
});

var List = function List(_ref) {
  var value = _ref.value,
      optionClick = _ref.optionClick,
      noOptionsTitle = _ref.noOptionsTitle,
      filterValue = _ref.filterValue,
      filterValueText = _ref.filterValueText,
      selectedValues = _ref.selectedValues,
      MenuProps = _ref.MenuProps,
      MenuItemProps = _ref.MenuItemProps;

  var _useStyles = useStyles(),
      menu = _useStyles.menu;

  return /*#__PURE__*/React.createElement(Menu, _extends({}, MenuProps, {
    className: clsx('bp3-elevation-1', menu, MenuProps.className)
  }), value.length < 1 && /*#__PURE__*/React.createElement(MenuItem, _extends({
    text: filterValue ? filterValueText : noOptionsTitle,
    disabled: true
  }, MenuItemProps)), value.length > 0 && value.map(function (_ref2) {
    var value = _ref2.value,
        label = _ref2.label,
        ItemMenuItemProps = _ref2.MenuItemProps;
    return /*#__PURE__*/React.createElement(MenuItem, _extends({
      onClick: function onClick(e) {
        return optionClick(e, value);
      },
      key: value,
      active: selectedValues.includes(value),
      text: label
    }, MenuItemProps, ItemMenuItemProps));
  }));
};

List.propTypes = {
  value: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })),
  optionClick: PropTypes.func.isRequired,
  noOptionsTitle: PropTypes.node,
  filterValue: PropTypes.string,
  filterValueText: PropTypes.node,
  selectedValues: PropTypes.array,
  checkboxVariant: PropTypes.bool,
  MenuProps: PropTypes.object,
  MenuItemProps: PropTypes.object
};
List.defaultProps = {
  value: [],
  MenuProps: {},
  MenuItemProps: {}
};

var Toolbar = function Toolbar(_ref3) {
  var sortTitle = _ref3.sortTitle,
      onFilter = _ref3.onFilter,
      onSort = _ref3.onSort,
      sortDirection = _ref3.sortDirection,
      value = _ref3.value,
      placeholder = _ref3.placeholder,
      ControlGroupProps = _ref3.ControlGroupProps,
      InputGroupProps = _ref3.InputGroupProps,
      ButtonProps = _ref3.ButtonProps;
  return /*#__PURE__*/React.createElement(ControlGroup, ControlGroupProps, /*#__PURE__*/React.createElement(InputGroup, _extends({
    placeholder: placeholder,
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    value: value
  }, InputGroupProps)), /*#__PURE__*/React.createElement(Button, _extends({
    icon: sortDirection ? 'sort-desc' : 'sort-asc',
    title: sortTitle,
    onClick: onSort
  }, ButtonProps)));
};

Toolbar.propTypes = {
  sortTitle: PropTypes.node,
  onFilter: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  sortDirection: PropTypes.bool,
  value: PropTypes.string,
  placeholder: PropTypes.string,
  ControlGroupProps: PropTypes.object,
  InputGroupProps: PropTypes.object,
  ButtonProps: PropTypes.object
};
Toolbar.defaultProps = {
  ControlGroupProps: {},
  InputGroupProps: {},
  ButtonProps: {}
};

var DualListInternal = function DualListInternal(_ref4) {
  var allToRight = _ref4.allToRight,
      allToLeft = _ref4.allToLeft,
      leftTitle = _ref4.leftTitle,
      moveAllLeftTitle = _ref4.moveAllLeftTitle,
      moveAllRightTitle = _ref4.moveAllRightTitle,
      moveRightTitle = _ref4.moveRightTitle,
      moveLeftTitle = _ref4.moveLeftTitle,
      rightTitle = _ref4.rightTitle,
      noValueTitle = _ref4.noValueTitle,
      noOptionsTitle = _ref4.noOptionsTitle,
      filterOptionsTitle = _ref4.filterOptionsTitle,
      filterValueTitle = _ref4.filterValueTitle,
      filterValueText = _ref4.filterValueText,
      filterOptionsText = _ref4.filterOptionsText,
      state = _ref4.state,
      sortOptions = _ref4.sortOptions,
      filterOptions = _ref4.filterOptions,
      handleOptionsClick = _ref4.handleOptionsClick,
      leftValues = _ref4.leftValues,
      handleMoveRight = _ref4.handleMoveRight,
      handleMoveLeft = _ref4.handleMoveLeft,
      handleClearLeftValues = _ref4.handleClearLeftValues,
      handleClearRightValues = _ref4.handleClearRightValues,
      sortValues = _ref4.sortValues,
      filterValues = _ref4.filterValues,
      rightValues = _ref4.rightValues,
      handleValuesClick = _ref4.handleValuesClick,
      WrapperProps = _ref4.WrapperProps,
      LeftWrapperProps = _ref4.LeftWrapperProps,
      RightWrapperProps = _ref4.RightWrapperProps,
      ButtonGroupProps = _ref4.ButtonGroupProps,
      ToRightButtonProps = _ref4.ToRightButtonProps,
      AllToRightButtonProps = _ref4.AllToRightButtonProps,
      AllToLeftButtonProps = _ref4.AllToLeftButtonProps,
      ToLeftButtonProps = _ref4.ToLeftButtonProps,
      LeftControlGroupProps = _ref4.LeftControlGroupProps,
      LeftInputGroupProps = _ref4.LeftInputGroupProps,
      LeftButtonProps = _ref4.LeftButtonProps,
      RightControlGroupProps = _ref4.RightControlGroupProps,
      RightInputGroupProps = _ref4.RightInputGroupProps,
      RightButtonProps = _ref4.RightButtonProps,
      LeftMenuProps = _ref4.LeftMenuProps,
      LeftMenuItemProps = _ref4.LeftMenuItemProps,
      RightMenuProps = _ref4.RightMenuProps,
      RightMenuItemProps = _ref4.RightMenuItemProps,
      leftSortTitle = _ref4.leftSortTitle,
      rightSortTitle = _ref4.rightSortTitle;

  var _useStyles2 = useStyles(),
      buttonGroup = _useStyles2.buttonGroup,
      wrapper = _useStyles2.wrapper;

  return /*#__PURE__*/React.createElement("div", _extends({}, WrapperProps, {
    className: clsx(wrapper, WrapperProps.className)
  }), /*#__PURE__*/React.createElement("div", LeftWrapperProps, leftTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    onFilter: filterOptions,
    value: state.filterOptions,
    placeholder: filterOptionsTitle,
    ControlGroupProps: LeftControlGroupProps,
    InputGroupProps: LeftInputGroupProps,
    ButtonProps: LeftButtonProps,
    sortTitle: leftSortTitle
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleOptionsClick,
    value: leftValues,
    noOptionsTitle: noOptionsTitle,
    filterValue: state.filterOptions,
    filterValueText: filterOptionsText,
    selectedValues: state.selectedLeftValues,
    MenuProps: LeftMenuProps,
    MenuItemProps: LeftMenuItemProps
  })), /*#__PURE__*/React.createElement(ButtonGroup, _extends({
    vertical: true,
    alignText: "center"
  }, ButtonGroupProps, {
    className: clsx(buttonGroup, ButtonGroupProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedLeftValues.length === 0,
    onClick: handleMoveRight,
    title: moveRightTitle,
    icon: "chevron-right"
  }, ToRightButtonProps)), allToRight && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: leftValues.length === 0,
    onClick: handleClearLeftValues,
    title: moveAllRightTitle,
    icon: "double-chevron-right"
  }, AllToRightButtonProps)), allToLeft && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: rightValues.length === 0,
    onClick: handleClearRightValues,
    title: moveAllLeftTitle,
    icon: "double-chevron-left"
  }, AllToLeftButtonProps)), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedRightValues.length === 0,
    onClick: handleMoveLeft,
    title: moveLeftTitle,
    icon: "chevron-left"
  }, ToLeftButtonProps))), /*#__PURE__*/React.createElement("div", RightWrapperProps, rightTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    onFilter: filterValues,
    value: state.filterValue,
    placeholder: filterValueTitle,
    ControlGroupProps: RightControlGroupProps,
    InputGroupProps: RightInputGroupProps,
    ButtonProps: RightButtonProps,
    sortTitle: rightSortTitle
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleValuesClick,
    value: rightValues,
    noOptionsTitle: noValueTitle,
    filterValue: state.filterValue,
    filterValueText: filterValueText,
    selectedValues: state.selectedRightValues,
    MenuProps: RightMenuProps,
    MenuItemProps: RightMenuItemProps
  })));
};

DualListInternal.propTypes = {
  leftTitle: PropTypes.node,
  rightTitle: PropTypes.node,
  moveLeftTitle: PropTypes.node,
  moveRightTitle: PropTypes.node,
  allToLeft: PropTypes.bool,
  allToRight: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  moveAllLeftTitle: PropTypes.node,
  moveAllRightTitle: PropTypes.node,
  noValueTitle: PropTypes.node,
  noOptionsTitle: PropTypes.node,
  filterOptionsTitle: PropTypes.node,
  filterValueTitle: PropTypes.node,
  filterValueText: PropTypes.node,
  filterOptionsText: PropTypes.node,
  state: PropTypes.object,
  sortOptions: PropTypes.func,
  filterOptions: PropTypes.func,
  handleOptionsClick: PropTypes.func,
  leftValues: PropTypes.array,
  handleMoveRight: PropTypes.func,
  handleMoveLeft: PropTypes.func,
  handleClearLeftValues: PropTypes.func,
  handleClearRightValues: PropTypes.func,
  sortValues: PropTypes.func,
  filterValues: PropTypes.func,
  rightValues: PropTypes.array,
  handleValuesClick: PropTypes.func,
  WrapperProps: PropTypes.object,
  LeftWrapperProps: PropTypes.object,
  RightWrapperProps: PropTypes.object,
  ButtonGroupProps: PropTypes.object,
  ToRightButtonProps: PropTypes.object,
  AllToRightButtonProps: PropTypes.object,
  AllToLeftButtonProps: PropTypes.object,
  ToLeftButtonProps: PropTypes.object,
  LeftControlGroupProps: PropTypes.object,
  LeftInputGroupProps: PropTypes.object,
  LeftButtonProps: PropTypes.object,
  RightControlGroupProps: PropTypes.object,
  RightInputGroupProps: PropTypes.object,
  RightButtonProps: PropTypes.object,
  LeftMenuProps: PropTypes.object,
  LeftMenuItemProps: PropTypes.object,
  RightMenuProps: PropTypes.object,
  RightMenuItemProps: PropTypes.object,
  leftSortTitle: PropTypes.string,
  rightSortTitle: PropTypes.string
};
DualListInternal.defaultProps = {
  leftTitle: 'Options',
  rightTitle: 'Selected',
  moveLeftTitle: 'Move selected to left',
  moveRightTitle: 'Move selected to right',
  moveAllRightTitle: 'Move all to right',
  moveAllLeftTitle: 'Move all to left',
  noOptionsTitle: 'No available options',
  noValueTitle: 'No selected',
  filterOptionsTitle: 'Filter options',
  filterValueTitle: 'Filter selected value',
  filterOptionsText: 'Remove your filter to see all options',
  filterValueText: 'Remove your filter to see all selected',
  leftSortTitle: 'Sort options',
  rightSortTitle: 'Sort value',
  options: [],
  allToLeft: true,
  allToRight: true,
  WrapperProps: {},
  LeftWrapperProps: {},
  RightWrapperProps: {},
  ButtonGroupProps: {},
  ToRightButtonProps: {},
  AllToRightButtonProps: {},
  AllToLeftButtonProps: {},
  ToLeftButtonProps: {},
  LeftControlGroupProps: {},
  LeftInputGroupProps: {},
  LeftButtonProps: {},
  RightControlGroupProps: {},
  RightInputGroupProps: {},
  RightButtonProps: {},
  LeftMenuProps: {},
  LeftMenuItemProps: {},
  RightMenuProps: {},
  RightMenuItemProps: {}
};

var DualListWrapper = function DualListWrapper(props) {
  return /*#__PURE__*/React.createElement(FormGroupInternal, _extends({}, props, {
    Component: DualListInternal
  }));
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualListWrapper
  }));
};

export default DualListSelect;
